@@ -4,4 +4,6 @@ from .download import to_csv, download
 from .errors import remove_errors
 from .name_normalizer import usa_county_to_fips
 from .party_normalizer import usa_party_normalizer, MultiPartyResolver
-from .utils import remove_non_first_rank
+from .utils import remove_non_first_rank, columns_for_variable
+
+from . import examples
\ No newline at end of file
